{% extends 'base.html' %}
{% load buttons %}

{% block content %}
<h1>{% block title %}Software Providers{% endblock %}</h1>
<div class="row">
   <div class="col-md-9">
     {% include 'utilities/obj_table.html' %}
    </div>
	<div class="col-md-3 noprint">
		{% include 'inc/search_panel.html' %}
	</div>
</div>
{% endblock %}

